@@ -2,10 +2,10 @@
 #define _TYPEDEFS_H_
 
 /******** Definition of items with uniquely size **********
-(c) 1997-2020 Jaroslav Fojtik
+(c) 1997-2021 Jaroslav Fojtik
    if you don't use below mentionted compiler, please correct this items
    for your compiler and send me your correction to:
-			fojtik@penguin.cz or JaFojtik@seznam.cz
+			fojtik@penguin.cz or JaFojtik@yandex.com
 
 List of supported types:
 
@@ -192,7 +192,7 @@ extern "C" {
  #define WORD    __u16
  #define SWORD   __s16
  #define SDWORD  __s32
- #if defined(__u64_defined) 
+ #if defined(__u64_defined)
   #define QWORD  __u64
   #define SQWORD __s64
  #endif
