@@ -7,6 +7,15 @@
  ******************************************************************************/
 #include "cplib.cc"
 
+#if defined(__DJGPP__) || defined(_WIN32)
+ #define DIR_DEPARATOR '\\'
+#else
+ #define DIR_DEPARATOR '/'
+#endif
+
+
+const char *Directory = NULL;
+
 
 doublelist ReadCodeGenerator(const char *FileName)
 {
@@ -17,7 +26,7 @@ int i;
 
   if(FileName==NULL) return result;
   if(*FileName==0) return result;
-  F=fopen(FileName,"rb");
+  F = fopen(FileName,"rb");
   if(F==NULL) return result;
 
   result.Flip(1);
@@ -226,6 +235,14 @@ return plain;
 }
 
 
+void ForgeFname(string &str, const char *Fname)
+{
+ str = Directory;
+ if(str.length()>0) str+=DIR_DEPARATOR;
+ str += Fname;
+}
+
+
 void WriteCodeGenerator(doublelist & WP2LaTeX, const char *Table, const char *Switch)
 {
 FILE *F, *Fcp;
@@ -233,7 +250,7 @@ int i, j;
 doublelist SimpleTable;
 unsigned TablePosStart;
 
- j=0;
+ j = 0;
  for(i=0; i<WP2LaTeX.length(); i++)
    {
    string s2(WP2LaTeX.Member(i,1));
@@ -371,11 +388,11 @@ unsigned TablePosStart;
 }
 
 
-int main(void)
+int main(int argc, char *argv[])
 {
 FILE *F;
 codepage internal;
-codepage cp852, cp1250, cp1251, cp1252, cp1276, cpkam,
+codepage cp852, cp1250, cp1251, cp1252, cp1253, cp1276, cpkam,
          cpwp4a, cpwp5, cpwp5_cz, cpwp6,
 	 iso_8859_1, iso_8859_2, iso_8859_3, iso_8859_4,
          unicode,koi8cs,koi8r,
@@ -385,73 +402,95 @@ codepage cphtml;
 codepage symbol;
 Translator trn;
 doublelist llHTML;
-//doublelist WP2LaTeX;
+string FileName;
 
-puts("<<<cplib>>> (c)1999-2021 J.Fojtik");
-//printf("%ld\n",coreleft());
+ puts("<<<cplib>>> (c)1999-2021 J.Fojtik");
 
-doublelist WP2LaTeX(ReadCodeGenerator("chars.c_"));
-//WP2LaTeX.doublelist::operator=(WP2LaTeX,ReadCodeGenerator("chars.c_"));
+ if(argc>1)
+   {
+   int i = 0;
+   while(++i < argc)
+     {
+     if(!strcmp(argv[i],"-dir"))
+	{
+	i++;
+	if(i<argc) Directory=argv[i];
+	}
+     }
+   }
 
-WP2LaTeX.Flip(0);
-WriteCodeGenerator(WP2LaTeX,"internal.enc","charactr.cc_");
-WP2LaTeX.erase();
+ //printf("\n dir=%s.",Directory);
 
-LoadCodePage("internal",internal);
-LoadCodePage("unicode", unicode,0);
+ //printf("%ld\n",coreleft());
 
-LoadCodePage("cp852",cp852,0);
-LoadCodePage("cp1250",cp1250,0);
-LoadCodePage("cp1251",cp1251,0);
-LoadCodePage("cp1252",cp1252,0);
-LoadCodePage("kam",cpkam,0);
+ doublelist WP2LaTeX(ReadCodeGenerator("chars.c_"));
+ //WP2LaTeX.doublelist::operator=(WP2LaTeX,ReadCodeGenerator("chars.c_"));
 
-LoadCodePage("wp6",cpwp6,0);
-LoadCodePage("wp5",cpwp5,0);
-LoadCodePage("wp5_cz",cpwp5_cz,0);
-LoadCodePage("wp4a",cpwp4a,0);
-LoadCodePage("is8859_1",iso_8859_1,0);
-LoadCodePage("is8859_2",iso_8859_2,0);
-LoadCodePage("is8859_3",iso_8859_3,0);
-LoadCodePage("is8859_4",iso_8859_4,0);
-if(iso_8859_1.name) {free(iso_8859_1.name);iso_8859_1.name=strdup("iso_8859_1");}
-if(iso_8859_2.name) {free(iso_8859_2.name);iso_8859_2.name=strdup("iso_8859_2");}
-if(iso_8859_3.name) {free(iso_8859_3.name);iso_8859_3.name=strdup("iso_8859_3");}
-if(iso_8859_4.name) {free(iso_8859_4.name);iso_8859_4.name=strdup("iso_8859_4");}
+ WP2LaTeX.Flip(0);
+ ForgeFname(FileName, "internal.enc");
+ WriteCodeGenerator(WP2LaTeX,FileName(),"charactr.cc_");
+ WP2LaTeX.erase();
 
-LoadCodePage("koi8cs",koi8cs,0);
-LoadCodePage("koi8_r",koi8r,0);
+ ForgeFname(FileName, "internal");
+ LoadCodePage(FileName(), internal);
+ LoadCodePage("unicode", unicode,0);
 
-LoadCodePage("mtef2",mtef2,0);
-LoadCodePage("symbol",symbol,0);
+ LoadCodePage("cp852",cp852,0);
+ LoadCodePage("cp1250",cp1250,0);
+ LoadCodePage("cp1251",cp1251,0);
+ LoadCodePage("cp1252",cp1252,0);
+ LoadCodePage("cp1253",cp1253,0);
+ LoadCodePage("kam",cpkam,0);
 
-LoadCodePage("mac_roma",MAC_ROMAN,0);
-if(MAC_ROMAN.name){free(MAC_ROMAN.name);MAC_ROMAN.name=strdup("MacRoman");}
+ LoadCodePage("wp6",cpwp6,0);
+ LoadCodePage("wp5",cpwp5,0);
+ LoadCodePage("wp5_cz",cpwp5_cz,0);
+ LoadCodePage("wp4a",cpwp4a,0);
+ LoadCodePage("is8859_1",iso_8859_1,0);
+ LoadCodePage("is8859_2",iso_8859_2,0);
+ LoadCodePage("is8859_3",iso_8859_3,0);
+ LoadCodePage("is8859_4",iso_8859_4,0);
+ if(iso_8859_1.name) {free(iso_8859_1.name);iso_8859_1.name=strdup("iso_8859_1");}
+ if(iso_8859_2.name) {free(iso_8859_2.name);iso_8859_2.name=strdup("iso_8859_2");}
+ if(iso_8859_3.name) {free(iso_8859_3.name);iso_8859_3.name=strdup("iso_8859_3");}
+ if(iso_8859_4.name) {free(iso_8859_4.name);iso_8859_4.name=strdup("iso_8859_4");}
 
-LoadCodePage("cp1276",cp1276,0);
+ LoadCodePage("koi8cs",koi8cs,0);
+ LoadCodePage("koi8_r",koi8r,0);
 
-//if(heapcheck()<=0)
-//	asm int 3;
-printf("%ld\n",coreleft());
+ LoadCodePage("mtef2",mtef2,0);
+ LoadCodePage("symbol",symbol,0);
+
+ LoadCodePage("mac_roma",MAC_ROMAN,0);
+ if(MAC_ROMAN.name){free(MAC_ROMAN.name);MAC_ROMAN.name=strdup("MacRoman");}
+
+ LoadCodePage("cp1276",cp1276,0);
+
+ //if(heapcheck()<=0)
+ //	asm int 3;
+ printf("%ld\n",coreleft());
 
 
+ ForgeFname(FileName, "trn.trn");
+ if((F=fopen(FileName(),"w"))==NULL)
+ {
+   printf("Cannot write to the file \"%s\"", FileName());
+   return -1;
+ }
+ fprintf(F,"/*Do not edit this file, it is generated automatically from .enc files*/\n");
 
 
-if((F=fopen("trn.trn","w"))==NULL) return(0);
-fprintf(F,"/*Do not edit this file, it is generated automatically from .enc files*/\n");
+ CreateTranslator(trn,cpwp4a, internal);
+ WriteTranslator(cpwp4a,internal,trn,F);
 
+ CreateTranslator(trn,cpwp5, internal);
+ WriteTranslator(cpwp5,internal,trn,F);
 
-CreateTranslator(trn,cpwp4a, internal);
-WriteTranslator(cpwp4a,internal,trn,F);
+ CreateTranslator(trn,cpwp5_cz, internal);
+ WriteTranslator(cpwp5_cz,internal,trn,F);
 
-CreateTranslator(trn,cpwp5, internal);
-WriteTranslator(cpwp5,internal,trn,F);
-
-CreateTranslator(trn,cpwp5_cz, internal);
-WriteTranslator(cpwp5_cz,internal,trn,F);
-
-CreateTranslator(trn,cpwp6, internal);
-WriteTranslator(cpwp6,internal,trn,F);
+ CreateTranslator(trn,cpwp6, internal);
+ WriteTranslator(cpwp6,internal,trn,F);
 
 
 
@@ -476,104 +515,131 @@ WriteTranslator(cp1250,cpkam,trn,F);
 */
 
 //end:
-fclose(F);
+ fclose(F);
 
 
-LoadTextCodePage("html",llHTML);
-llHTML.sort(strcmp);
-CreateCodePage("html",cphtml,llHTML);
-if((F=fopen("html.trn","w"))==NULL) return(0);
-fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
-CreateTranslator(trn,cphtml, internal);
-WriteTranslator(cphtml,internal,trn,F);
-WriteStringTable(F,cphtml,llHTML);
-fclose(F);
+ LoadTextCodePage("html",llHTML);
+ llHTML.sort(strcmp);
+ CreateCodePage("html",cphtml,llHTML);
+
+ ForgeFname(FileName, "html.trn");
+ if((F=fopen(FileName(),"w"))==NULL)
+ {
+   printf("Cannot write to the file \"%s\"", FileName());
+   return -3;
+ }
+ fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
+ CreateTranslator(trn,cphtml, internal);
+ WriteTranslator(cphtml,internal,trn,F);
+ WriteStringTable(F,cphtml,llHTML);
+ fclose(F);
 
 
-if((F=fopen("cpg.trn","w"))==NULL) return(0);
-fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
-CreateTranslator(trn,cpkam,internal);
-WriteTranslator(cpkam,internal,trn,F);
+ FileName=Directory; 
+ if(FileName.length()>0) FileName+=DIR_DEPARATOR;
+ FileName += "cpg.trn";
+ if((F=fopen(FileName(),"w"))==NULL)
+ {
+   printf("Cannot write to the file \"%s\"", FileName());
+   return -2;
+ }
+ fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
+ CreateTranslator(trn,cpkam,internal);
+ WriteTranslator(cpkam,internal,trn,F);
 
-CreateTranslator(trn,iso_8859_1,internal);
-WriteTranslator(iso_8859_1,internal,trn,F);
+ CreateTranslator(trn,iso_8859_1,internal);
+ WriteTranslator(iso_8859_1,internal,trn,F);
 
-CreateTranslator(trn,iso_8859_2,internal);
-WriteTranslator(iso_8859_2,internal,trn,F);
+ CreateTranslator(trn,iso_8859_2,internal);
+ WriteTranslator(iso_8859_2,internal,trn,F);
 
-CreateTranslator(trn,iso_8859_3,internal);
-WriteTranslator(iso_8859_3,internal,trn,F);
+ CreateTranslator(trn,iso_8859_3,internal);
+ WriteTranslator(iso_8859_3,internal,trn,F);
 
-CreateTranslator(trn,iso_8859_4,internal);
-WriteTranslator(iso_8859_4,internal,trn,F);
+ CreateTranslator(trn,iso_8859_4,internal);
+ WriteTranslator(iso_8859_4,internal,trn,F);
 
-CreateTranslator(trn,cp852,internal);
-WriteTranslator(cp852,internal,trn,F);
+ CreateTranslator(trn,cp852,internal);
+ WriteTranslator(cp852,internal,trn,F);
 
-CreateTranslator(trn,cp1250,internal);
-WriteTranslator(cp1250,internal,trn,F);
+ CreateTranslator(trn,cp1250,internal);
+ WriteTranslator(cp1250,internal,trn,F);
 
-CreateTranslator(trn,cp1251,internal);
-WriteTranslator(cp1251,internal,trn,F);
+ CreateTranslator(trn,cp1251,internal);
+ WriteTranslator(cp1251,internal,trn,F);
 
-CreateTranslator(trn,cp1252,internal);
-WriteTranslator(cp1252,internal,trn,F);
+ CreateTranslator(trn,cp1252,internal);
+ WriteTranslator(cp1252,internal,trn,F);
 
-CreateTranslator(trn,unicode,internal);
-WriteTranslator(unicode,internal,trn,F);
+ CreateTranslator(trn,cp1253,internal);
+ WriteTranslator(cp1253,internal,trn,F);
 
-CreateTranslator(trn,koi8cs,internal);
-WriteTranslator(koi8cs,internal,trn,F);
+ CreateTranslator(trn,unicode,internal);
+ WriteTranslator(unicode,internal,trn,F);
 
-CreateTranslator(trn,koi8r,internal);
-WriteTranslator(koi8r,internal,trn,F);
+ CreateTranslator(trn,koi8cs,internal);
+ WriteTranslator(koi8cs,internal,trn,F);
+
+ CreateTranslator(trn,koi8r,internal);
+ WriteTranslator(koi8r,internal,trn,F);
 
 	// *************** Output codepage generator *****************
-CreateTranslator(trn, internal, unicode);
-WriteTranslator(internal, unicode, trn, F);
+ CreateTranslator(trn, internal, unicode);
+ WriteTranslator(internal, unicode, trn, F);
 
-CreateTranslator(trn, internal, cp1276);
-WriteTranslator(internal, cp1276, trn, F);
+ CreateTranslator(trn, internal, cp1276);
+ WriteTranslator(internal, cp1276, trn, F);
 
-CreateTranslator(trn, internal, symbol);
-WriteTranslator(internal, symbol, trn, F);
+ CreateTranslator(trn, internal, symbol);
+ WriteTranslator(internal, symbol, trn, F);
 
 /*
-CreateTranslator(trn, internal, cp1250);
-WriteTranslator(internal, cp1250, trn, F);
+ CreateTranslator(trn, internal, cp1250);
+ WriteTranslator(internal, cp1250, trn, F);
 
-CreateTranslator(trn, internal, cp852);
-WriteTranslator(internal, cp852, trn, F);
+ CreateTranslator(trn, internal, cp852);
+ WriteTranslator(internal, cp852, trn, F);
 
-CreateTranslator(trn, internal, iso_8859_1);
-WriteTranslator(internal, iso_8859_1, trn, F);
+ CreateTranslator(trn, internal, iso_8859_1);
+ WriteTranslator(internal, iso_8859_1, trn, F);
 
-CreateTranslator(trn, internal, iso_8859_2);
-WriteTranslator(internal, iso_8859_2, trn, F);
+ CreateTranslator(trn, internal, iso_8859_2);
+ WriteTranslator(internal, iso_8859_2, trn, F);
 */
 
-fclose(F);
+ fclose(F);
 
 
-if((F=fopen("mtef.trn","w"))==NULL) goto SkipMtef;
-fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
-CreateTranslator(trn,symbol,internal);
-WriteTranslator(symbol,internal,trn,F);
+ ForgeFname(FileName, "mtef.trn");
+ if((F=fopen(FileName(),"w"))==NULL)
+ {
+   printf("Cannot write to the file \"%s\"", FileName());
+   goto SkipMtef;
+ }
 
-CreateTranslator(trn,mtef2,internal);
-WriteTranslator(mtef2,internal,trn,F);
-fclose(F);
+ fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
+ CreateTranslator(trn,symbol,internal);
+ WriteTranslator(symbol,internal,trn,F);
+
+ CreateTranslator(trn,mtef2,internal);
+ WriteTranslator(mtef2,internal,trn,F);
+ fclose(F);
 
 
 SkipMtef:
-if((F=fopen("macroman.trn","w"))==NULL) return(0);
-fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
-CreateTranslator(trn,MAC_ROMAN,internal);
-WriteTranslator(MAC_ROMAN,internal,trn,F);
-fclose(F);
+ ForgeFname(FileName, "macroman.trn");
+ if((F=fopen(FileName(),"w"))==NULL)
+ {
+   printf("Cannot write to the file \"%s\"", FileName());
+   return -3;
+ }
+ fprintf(F,"/*Do not edit this file. It is automatically generated.*/\n");
+ CreateTranslator(trn,MAC_ROMAN,internal);
+ WriteTranslator(MAC_ROMAN,internal,trn,F);
+ fclose(F);
 
 
-trn.erase();
+ trn.erase();
 
 return 0;
 }
\ No newline at end of file
