@@ -612,10 +612,10 @@ char LastC;
 string InternalArg;
 bool FirstCipher = false;
 
-  arg = "";
+  arg.erase();
 
-  while (str != "" && str[0] == ' ')
-    str=copy(str,1,length(str)-1);
+  while(str != "" && str[0] == ' ')
+    str = copy(str,1,length(str)-1);
 
   LastC = '\0';
   i = 0;
@@ -769,7 +769,7 @@ char c;
 char LastC, LastSupSub;
 string InternalArg;
 
-  arg = "";
+  arg.erase();
 
   while(str!="" && str[0]==' ')
     str=copy(str,1,length(str)-1);
@@ -887,7 +887,7 @@ int i,j;
 char c,LastC;
 
   LastC=0;
-  arg = "";
+  arg.erase();
   while(str != "" && str[length(str) - 1] == ' ')
       {
       str = copy(str,0,length(str)-1);
@@ -982,7 +982,7 @@ char c, LastC;
 BYTE LastSupSub, LastCBrace;
 
   LastCBrace=LastSupSub=LastC=0;
-  arg = "";
+  arg.erase();
   while(str != "" && str[length(str) - 1] == ' ')
       {
       str=copy(str,0,length(str)-1);
@@ -1178,7 +1178,7 @@ void Interpret(TconvertedPass1 *cq, string & strB, string & strE,
 			case '2':Numeral=arg[2];seq++;break;
 			case '3':Numeral=arg[3];seq++;break;
 			case '4':Numeral=arg[4];seq++;break;
-			default: Numeral=""; break;
+			default: Numeral.erase(); break;
 			};
                   if(Numeral=="")
 		   	{
@@ -1224,7 +1224,12 @@ bool MathArray = false;
 
  if(StrStr(Str," \\nonumber ")!=NULL) MathArray=true;
 
- if(Box.AnchorType==2)
+ /*if(cq->envir=='B')
+   {
+   if(StrStr(Str," \\\\")!=NULL) MathArray=true;
+   } */
+
+ if(Box.AnchorType==2 || cq->envir=='B')
    {
    const char *pom,*pom2;
    pom = pom2 = "";
@@ -1233,7 +1238,7 @@ bool MathArray = false;
 	pom="\\begin{array}{c}";
 	pom2="\\end{array}";
 	}
-   if (cq->attr.Math_Depth)
+   if(cq->attr.Math_Depth)
 	       fprintf(cq->strip, "}{%s%s%s}{\\rm ",pom,Str,pom2);
 	  else fprintf(cq->strip, " $%s%s%s$ ",pom,Str,pom2);
 
@@ -1280,10 +1285,14 @@ bool MathArray = false;
 
  while(Str!=NULL)
    {
-   char *pom = StrStr(Str,"\\\\");	// Look for all internal formula delimiters.
-   if(pom!=NULL) *pom=0;
-
-   fputs(Str,cq->strip);		// Output a current line.
+   char *pom = StrStr(Str,"\\\\");  // Look for all internal formula delimiters.
+   if(pom!=NULL)
+   {
+     fwrite(Str,1,pom-Str,cq->strip);
+     *pom = 0;				// the \n character will be searched in a current line.
+   }
+   else
+       fputs(Str,cq->strip);		// Output a current line.
 
    Str = StrChr(Str,'\n');		// All new lines in formula must be also handled.
    while(Str!=NULL)
@@ -1477,11 +1486,11 @@ BYTE styles;
 	}
 // if(cq->log!=NULL) fprintf(cq->log,"\n%s\n",StrBeg.ch);
 
-  StrEnd = "";
+  StrEnd.erase();
   for(i=0; i<nFmlTransWords; i++)
       {
       StrEnd = StrBeg + StrEnd;
-      StrBeg = "";
+      StrBeg.erase();
 
       while(RemoveSymbol(StrBeg, StrEnd, FmlTransTable[i].szWP))
 	   {
@@ -1530,7 +1539,9 @@ BYTE styles;
 			}
 		}
 
-	   arg[0] = arg[1] = arg[2] = "";
+	   arg[0].erase();
+           arg[1].erase();
+	   arg[2].erase();
 
 	   if(strstr(FmlTransTable[i].szTeX, "8") != NULL)
 	       {
@@ -1563,7 +1574,7 @@ BYTE styles;
       }
 
   StrEnd = StrBeg + StrEnd; /* Fix double superscript/subscript */  
-  StrBeg = "";
+  StrBeg.erase();
 
 	// Check braces \left and \right
   if(CheckFormulaLeftRight(StrEnd(),i,j))
@@ -1582,7 +1593,7 @@ BYTE styles;
       }
 
     StrEnd = StrBeg + StrEnd;
-    StrBeg = "";
+    StrBeg.erase();
     while(i>0 && RemoveSymbol(StrBeg, StrEnd, "\\left"))
     {
       Remove1stArg(StrEnd, arg[1]);
@@ -1604,13 +1615,13 @@ BYTE styles;
       StrEnd += "\\right .";
       }
     StrEnd = StrBeg + StrEnd;
-    StrBeg = "";
+    StrBeg.erase();
   }
 
   FixSubSup(StrBeg,StrEnd);
 
   StrBeg += StrEnd; /* Prepare equation for writing */
-  StrEnd = "";
+  StrEnd.erase();
 
   StrBeg = FixMultiplePrime(StrBeg);
 
@@ -1760,7 +1771,7 @@ string & FixFormulaStrFromTeX(string & StrEnd, const char chr_set)
       StrBeg += "\\i";		// There is some larger command like \isomething.
   }
   StrEnd = StrBeg + StrEnd;
-  StrBeg = "";
+  StrBeg.erase();
   while(RemoveSymbol(StrBeg, StrEnd, "\\j"))
   {
     if(StrEnd.length()<=0 || !isalpha(StrEnd[0]))
@@ -1769,7 +1780,7 @@ string & FixFormulaStrFromTeX(string & StrEnd, const char chr_set)
       StrBeg += "\\j";		// There is some larger command like \jsomething.
   }
   StrEnd = StrBeg + StrEnd;
-  StrBeg = "";
+  StrBeg.erase();
 
 	// https://www.maths.tcd.ie/~dwilkins/LaTeXPrimer/MathAccents.html
   StrEnd = replacesubstring(StrEnd,"\\'","\2acute ");
