@@ -415,11 +415,17 @@ typedef enum
 
 typedef enum
 {
-  EPS_DrawElipse =   1,
-  EPS_colorimage =   2,
-  EPS_rlecmapimage = 4,
-  EPS_accentshow  =  8,
-  EPS_ACCENTSHOW  = 16,
+  EPS_DrawElipse =    1,
+  EPS_colorimage =    2,
+  EPS_rlecmapimage =  4,
+  EPS_accentshow  =   8,
+  EPS_ACCENTSHOW  =  16,
+  EPS_FillBox1    =  32,
+  EPS_FillBox2    =  64,
+  EPS_FillPlus	  = 128,
+  EPS_FillBalls	  = 256,
+  EPS_FillTriangle= 512,
+  EPS_FillSmSquare=1024
 } EPS_COMPONENTS;
 
 
