@@ -400,7 +400,9 @@ const char *ch;
 }
 
 
-/** Solve attributes for columns in table header. */
+/** Solve attributes for columns in table header.
+ * @param[in]	 Attributes	Bit mask containing attributes.
+ * @return 	LaTeX string that causes selected attributes to close. */
 string Attributes2String(DWORD Attributes)
 {
 string TexAttrib;
@@ -1872,7 +1874,7 @@ const char *FontTblItem;
 		goto Found;
 		}
 	}
-   TexFontName="";		/*Font name was not found in the table*/
+   TexFontName.erase();		/*Font name was not found in the table*/
    }
 
 Found:
