@@ -427,7 +427,7 @@ unsigned char OldFlag;
  flag = Nothing;
 
  do {
-    TAG = "";
+    TAG.erase();
     ProcessKeyABI();
     if(by==ABI_META && subby==1) break;
     if(by==ABI_SECTMETA && subby==1) break;
@@ -458,7 +458,7 @@ flag = Nothing;
 recursion++;
 
 do {
-   TAG = "";
+   TAG.erase();
    ProcessKeyABI();
    if(by==ABI_TABLE)
      {
@@ -757,7 +757,7 @@ DWORD fsize;
       if(Verbosing >= 1)		//actualise a procentage counter
 	      perc.Actualise(ActualPos);
 
-      TAG = "";
+      TAG.erase();
       ProcessKeyABI();
       }
 
