@@ -21,12 +21,12 @@
 #include"wp2latex.h"
 #include"pass1xml.h"
 #include "cp_lib/cptran.h"
-#include "cp_lib/html.trn"
+#include "cp_lib/out_dir/html.trn"
 
 
 list HTMLChars(Table_html,sizeof(Table_html)/sizeof(char *));
 
-#define HTMLVersion "0.26"
+#define HTMLVersion "0.28"
 
 
 /** Base class for HTML document conversion. */
@@ -483,7 +483,7 @@ OldFlag = flag;
 flag = Nothing;
 
 do {
-   TAG = "";
+   TAG.erase();
    ProcessKeyHTML();
    if(by==TAG_SCRIPT && subby==1) break;
    }while(!feof(wpd));
@@ -512,7 +512,7 @@ flag = Nothing;
 recursion++;
 
 do {
-   TAG = "";
+   TAG.erase();
    ProcessKeyHTML();
    if(by==TAG_TABLE)
      {
@@ -625,7 +625,7 @@ unsigned char OldFlag = flag;
  flag = Nothing;
 
  do {
-    TAG = "";
+    TAG.erase();
     ProcessKeyHTML();
     if(by==TAG_STYLE && subby==1) break;
     } while(!feof(wpd));
@@ -647,7 +647,7 @@ unsigned char OldFlag = flag;
 
  fprintf(strip, "\\title{");
  do {
-    TAG = "";
+    TAG.erase();
     ProcessKeyHTML();
     if(by==TAG_xTITLE) break;
     } while(!feof(wpd));
@@ -917,7 +917,7 @@ DWORD fsize;
       if(Verbosing >= 1)		//actualise a procentage counter
 	      perc.Actualise(ActualPos);
 
-      TAG = "";
+      TAG.erase();
       ProcessKeyHTML();
       }
 
