@@ -6,7 +6,7 @@
  *              It could be optionally not compiled with WP2LaTeX package.    *
  * licency:     GPL		                                              *
  ******************************************************************************/
-#define RTF_Ver "0.14"
+#define RTF_Ver "0.15"
 //TODO: Dodelat znak ? - maze mezeru pred sebou
 //      Autodetekce \section podle xref _TOCxxxxxx
 
@@ -285,7 +285,7 @@ RGBQuad RHT_Highlight[17]={
  {0xBF,0xBF,0xBF}};	//16 light gray
 
 
-/*This procedure converts hexadecimal block from RTF to ist original shape, block is ended by '}'*/
+/// This procedure converts hexadecimal block from RTF to ist original shape, block is ended by '}.
 static void HEX2BIN_Block(FILE *FileIn, FILE *FileOut)
 {
 char c;
@@ -406,7 +406,7 @@ static int ecParseSpecialProperty(TconvertedPass1_RTF *cq,IPROP iprop, int val)
 
 
 
-// Set the property identified by _iprop_ to the value _val_.
+/// Set the property identified by _iprop_ to the value _val_.
 static int ecApplyPropChange(TconvertedPass1_RTF *cq, int isym, int val)
 {
 #ifdef DEBUG
@@ -445,7 +445,7 @@ char *pb;
 
 // Change to the destination specified by idest.
 // There's usually more to do here than this...
-static int ecChangeDest(TconvertedPass1_RTF *cq,IDEST idest)
+static int ecChangeDest(TconvertedPass1_RTF *cq, IDEST idest)
 {
 #ifdef DEBUG
   fprintf(cq->log,"\n#ecChangeDest() ");fflush(cq->log);
@@ -462,8 +462,8 @@ static int ecChangeDest(TconvertedPass1_RTF *cq,IDEST idest)
 }
 
 
-// Route the character to the appropriate destination stream.
-static int ecParseChar(TconvertedPass1_RTF *cq,int ch)
+/// Route the character to the appropriate destination stream.
+static int ecParseChar(TconvertedPass1_RTF *cq, int ch)
 {
 #ifdef DEBUG
   fprintf(cq->log,"\n#ecParseChar(%c) ",ch);fflush(cq->log);
@@ -498,7 +498,7 @@ static int ecParseChar(TconvertedPass1_RTF *cq,int ch)
 }
 
 
-// Evaluate an RTF control that needs special processing.
+/// Evaluate an RTF control that needs special processing.
 static int ecParseSpecialKeyword(TconvertedPass1_RTF *cq,IPFN ipfn)
 {
 #ifdef DEBUG
@@ -729,7 +729,8 @@ static int RTFLoadKeyword(TconvertedPass1_RTF *cq)
 #endif
 int ch;
 
- cq->Parameter = cq->Keyword = "";
+ cq->Parameter.erase();
+ cq->Keyword.erase();
  cq->lParam=0;
  cq->isParam=false;
  if ((ch = getc(cq->wpd)) == EOF) return(0); //no Keyword
@@ -748,7 +749,8 @@ int ch;
 
  if(ch=='\\')
 	{
-	cq->Keyword = cq->Parameter = "";
+	cq->Keyword.erase();
+        cq->Parameter.erase();
 	if ((ch = getc(cq->wpd)) == EOF) return(0);
 	if (ch == '\'')
 	     {
@@ -782,7 +784,7 @@ int ch;
 	      if ((ch = getc(cq->wpd)) == EOF)
 		   {
 		   ungetc(*cq->Parameter(), cq->wpd);
-		   cq->Parameter = "";
+		   cq->Parameter.erase();
 		   return(203);		//unexpected EOF
 		   }
 	      }
