@@ -238,8 +238,7 @@ public:
 
      SWORD YOffset, XOffset;
      SWORD YExtent, XExtent;
-
-     SWORD PositionX, PositionY;
+     
      Image Img;     
      WORD MapMode;     
      FloatBBox bbx;
@@ -253,14 +252,13 @@ public:
 
 TconvertedPass1_xMF::TconvertedPass1_xMF(void)
 {
-  NoConvertImage = 0;
-  PositionX = PositionY = 0;
+  NoConvertImage = 0;  
   YOffset = XOffset = 0;
   YExtent = XExtent = 0;
   bbx.MinX=65537; bbx.MaxX=-32767; bbx.MinY=65537; bbx.MaxY=-32767;
   memset(&PSS, 0, sizeof(PSS));
   PSS.FillPattern = 1;
-  PSS.FontSizeW = PSS.FontSize = 1100/2.66;		// Default font size [mm]  
+  PSS.FontSizeW = PSS.FontSize = 1100/2.66;		// Default font size [mm]
   MapMode = MM_ANISOTROPIC;
   PsNativeCP = GetTranslator("internalTOcp1276");
   PsNativeSym = GetTranslator("internalTOsymbol");  
@@ -273,11 +271,12 @@ TconvertedPass1_xMF::TconvertedPass1_xMF(void)
 class TconvertedPass1_WMF: public TconvertedPass1_xMF
      {
 public:
-     //TconvertedPass1_WMF(void);
+     TconvertedPass1_WMF(void) {PositionX = PositionY = 0;}
 
      virtual int Convert_first_pass(void);
      virtual int Dispatch(int FuncNo, const void *arg);
 
+     SWORD PositionX, PositionY;
      _StandardMetaRecord WmfRec;
 
 protected:
@@ -522,7 +521,7 @@ BYTE Underline, Strikeout, Charset, OutPrecision, ClipPrecision, Quality, PitchA
   Rd_word(wpd, (WORD*)&Height);
   Rd_word(wpd, &Width);
   Rd_word(wpd, &Escapement);
-  Rd_word(wpd, (WORD*)&PSS.FontOrientation10);
+  Rd_word(wpd, (WORD*)&PSS.FontOrientation10);  
   Rd_word(wpd, &PSS.FontWeight);
   PSS.FontItallic = fgetc(wpd);
   Underline = fgetc(wpd);
@@ -544,12 +543,13 @@ BYTE Underline, Strikeout, Charset, OutPrecision, ClipPrecision, Quality, PitchA
 				break;
     case MAC_CHARSET:		ConvertCpg = GetTranslator("MacRomanTOinternal");
 				break;
+    case GREEK_CHARSET:		ConvertCpg = GetTranslator("cp1253TOinternal");							    
+				break;
     case SHIFTJIS_CHARSET:
     case HANGUL_CHARSET:
     case JOHAB_CHARSET:
     case GB2312_CHARSET:
-    case CHINESEBIG5_CHARSET:
-    case GREEK_CHARSET:
+    case CHINESEBIG5_CHARSET:    
     case TURKISH_CHARSET:
     case VIETNAMESE_CHARSET:
     case HEBREW_CHARSET:
@@ -557,12 +557,15 @@ BYTE Underline, Strikeout, Charset, OutPrecision, ClipPrecision, Quality, PitchA
     case BALTIC_CHARSET:    
     case THAI_CHARSET:
 
-    default: if(err!=NULL)
-               {
-               perc.Hide();
-               fprintf(err, _("\nUnsupported charset: %X."), (unsigned)Charset);
-               }
+    default:			ConvertCpg = NULL; break;
   }
+  
+  if(ConvertCpg == NULL)
+     {
+     perc.Hide();
+     fprintf(err, _("\nUnsupported charset: %X."), (unsigned)Charset);
+     }
+
   PSS.ConvertCpg = ConvertCpg;
 
   OutPrecision = fgetc(wpd);
@@ -570,15 +573,21 @@ BYTE Underline, Strikeout, Charset, OutPrecision, ClipPrecision, Quality, PitchA
   Quality = fgetc(wpd);
   PitchAndFamily = fgetc(wpd);
 
-  if(Height!=0) PSS.FontSize = labs(Height)/2.66;
+  sprintf(ObjType,"%s(H=%d,set=%u,rot=%d)", ObjName+1, (int)Height, (unsigned)Charset, PSS.FontOrientation10/10);
+
+  if(YExtent<0) PSS.FontOrientation10 = -PSS.FontOrientation10;
+  if(Height!=0)
+  {
+    if(Height>0)		// The font height is normally negative.
+	PSS.FontOrientation10 = -PSS.FontOrientation10;
+    PSS.FontSize = labs(Height)/2.66;
+  }
   if(Width!=0) 
     PSS.FontSizeW = Width/2.66;
   else
     PSS.FontSizeW = PSS.FontSize;
 
   ObjTab.AddObject(new vecFont(PSS));
-
-sprintf(ObjType,"%s(%d)", ObjName+1, (int)Height);
 }
 
 
@@ -1670,14 +1679,14 @@ int TconvertedPass1_WMFspec::Convert_first_pass(void)
   Checksum ^= hdr.Reserved;
 
   Checksum = (Checksum & 0x0000FFFFUL) ^ ((Checksum & 0xFFFF0000UL) >> 16);
-  if(Checksum!=hdr.Checksum)
+  if(Checksum != hdr.Checksum)
     {
     if(err != NULL)
       {      
       fprintf(err, _("\nWarning: Invalid WMF CRC %X, expected %X."),hdr.Checksum,Checksum);
       }
     }
-  }
+  }  // scope discards hdr
 
  return TconvertedPass1_WMF::Convert_first_pass();
 }
@@ -1701,9 +1710,16 @@ typedef struct _EnhancedMetaRecord
 class TconvertedPass1_EMF: public TconvertedPass1_xMF
 {
 public:
-     virtual int Convert_first_pass(void);
+    SDWORD PositionX, PositionY;
 
-     _EnhancedMetaRecord EmfRec;
+    TconvertedPass1_EMF(void) {PositionX = PositionY = 0;}
+
+    virtual int Convert_first_pass(void);
+
+    void parse_LineTo(VectorList &VectList);
+    void parse_MoveToEX(void);
+
+    _EnhancedMetaRecord EmfRec;
 };
 
 TconvertedPass1 *Factory_EMF(void) {return new TconvertedPass1_EMF;}
@@ -1880,12 +1896,72 @@ bool LoadEmfRecord(FILE *f, _EnhancedMetaRecord &EmfRec)
 }
 
 
+void TconvertedPass1_EMF::parse_MoveToEX(void)
+{
+#ifdef DEBUG
+  fprintf(log,"\n#TconvertedPass1_EMF::parse_MoveToEx() ");fflush(log);
+#endif
+static const char ObjName[] = "!MOVETOEX";
+
+  if(EmfRec.Size >= 8+8)
+    {    
+    Rd_dword(wpd, (DWORD*)&PositionX);		// @TODO: extend PositionX,Y to 32 bits.    
+    Rd_dword(wpd, (DWORD*)&PositionY);    
+    sprintf(ObjType,"%s(%d;%d)", ObjName+1, PositionX, PositionY);
+    }
+  else
+    strcpy(ObjType,ObjName);  
+}
+
+
+void TconvertedPass1_EMF::parse_LineTo(VectorList &VectList)
+{
+#ifdef DEBUG
+  fprintf(log,"\n#TconvertedPass1_EMF::parse_LineTo() ");fflush(log);
+#endif
+static const char ObjName[] = "!LINETO";
+
+  if(EmfRec.Size >= 8+8)
+  {
+    SDWORD LineX, LineY;
+
+    Rd_dword(wpd, (DWORD*)&LineY);
+    Rd_dword(wpd, (DWORD*)&LineX);
+
+    UpdateBBox(bbx, 0, PositionX, PositionY, LineX-PositionX, LineY-PositionY);
+
+    float *Points = (float*)malloc(4*sizeof(float));
+    if(Points!=NULL)
+    {
+      const float Scale = GetScale2PSU((TMapMode)MapMode);
+
+      Points[0] = PositionX * Scale;
+      Points[1] = PositionY * Scale;
+      Points[2] = LineX * Scale;
+      Points[3] = LineY * Scale;
+      VectorLine *pVecLine = new VectorLine(Points, 2);      
+
+      memcpy(&pVecLine->LineColor, &PSS.LineColor, sizeof(PSS.LineColor));  
+      pVecLine->Close = false;
+      VectList.AddObject(pVecLine); pVecLine=NULL;
+
+      strcpy(ObjType,ObjName+1);
+      return;
+    }
+  }
+
+  strcpy(ObjType,ObjName);
+}
+
+
 int TconvertedPass1_EMF::Convert_first_pass(void)
 {
 #ifdef DEBUG
   fprintf(log,"\n#Convert_pass1_EMF() ");fflush(log);
 #endif
 EMFHEAD EmfHead;
+int RetVal = 0;
+const unsigned short CodePageBk = OutCodePage;
 
   if(Verbosing >= 1) printf(_("Opening Windows Enhanced MetaFile:"));
 
@@ -1898,6 +1974,7 @@ EMFHEAD EmfHead;
 
   fseek(wpd, EmfRec.ParamFilePos+EmfRec.Size, SEEK_SET);
 
+  VectorList VectList;
   while(!feof(wpd) && LoadEmfRecord(wpd,EmfRec))
   {
     switch(EmfRec.Type)
@@ -1928,7 +2005,7 @@ EMFHEAD EmfHead;
       case EMR_SETTEXTCOLOR: strcpy(ObjType,"!SETTEXTCOLOR"); break;	// 0x00000018
       case EMR_SETBKCOLOR: strcpy(ObjType,"!SETBKCOLOR"); break;	// 0x00000019
       case EMR_OFFSETCLIPRGN: strcpy(ObjType,"!OFFSETCLIPRGN"); break;	// 0x0000001A
-      case EMR_MOVETOEX: strcpy(ObjType,"!MOVETOEX"); break;	// 0x0000001B
+      case EMR_MOVETOEX:		parse_MoveToEX(); break;	// 0x0000001B
       case EMR_SETMETARGN: strcpy(ObjType,"!SETMETARGN"); break;	// 0x0000001C
       case EMR_EXCLUDECLIPRECT: strcpy(ObjType,"!EXCLUDECLIPRECT"); break;	// 0x0000001D
       case EMR_INTERSECTCLIPRECT: strcpy(ObjType,"!INTERSECTCLIPRECT"); break;	// 0x0000001E
@@ -1955,7 +2032,7 @@ EMFHEAD EmfHead;
       case EMR_RESIZEPALETTE: strcpy(ObjType,"!RESIZEPALETTE"); break;	// 0x00000033
       case EMR_REALIZEPALETTE: strcpy(ObjType,"!REALIZEPALETTE"); break;	// 0x00000034
       case EMR_EXTFLOODFILL: strcpy(ObjType,"!EXTFLOODFILL"); break;	// 0x00000035
-      case EMR_LINETO: strcpy(ObjType,"!LINETO"); break;	// 0x00000036
+      case EMR_LINETO:		parse_LineTo(VectList); break;	// 0x00000036
       case EMR_ARCTO: strcpy(ObjType,"!ARCTO"); break;	// 0x00000037
       case EMR_POLYDRAW: strcpy(ObjType,"!POLYDRAW"); break;	// 0x00000038
       case EMR_SETARCDIRECTION: strcpy(ObjType,"!SETARCDIRECTION"); break;	// 0x00000039
@@ -2027,7 +2104,7 @@ EMFHEAD EmfHead;
     
     if(log!=NULL)
     {   /**/
-      fprintf(log, _("\n%*s{EMF function:%3Xh; size:%4lu; pos:%lXh}"),
+      fprintf(log, _("\n%*s{EMF func:%3Xh; size:%4lu; pos:%lXh}"),
 		recursion*2,"",EmfRec.Type, (long)2*EmfRec.Size, (long)EmfRec.ParamFilePos);
       if(*ObjType!=0) fprintf(log," %s",ObjType);
     }
@@ -2036,11 +2113,133 @@ EMFHEAD EmfHead;
     fseek(wpd, ActualPos, SEEK_SET);    
   }
 
-  if(err != NULL)
-  {      
-    fprintf(err, _("\nEMF conversion is not supported yet!"));	/// @TODO: dopsat!
+  const float Scale = GetScale2PSU((TMapMode)MapMode) * 25.4f / 71.0f;	// convert PSu to WPGu (quite bad).
+  vFlip flipTrx(bbx.MinY, bbx.MaxY);
+
+  Image *Img2 = &Img;
+    while(Img2!=NULL)
+    {      
+      if(Img2->Raster!=NULL)
+      {        
+        if(Img2->dy<0)
+        {
+          Img2->dy = -Img2->dy;
+          //Img2->y += Img2->dy;                    
+        }
+        Flip2D(Img2->Raster);
+        if(Img2->dx<0)
+        {        
+         Img2->x += Img2->dx;
+         Img2->dx = -Img2->dx;
+         Flip1D(Img2->Raster);
+        }
+
+        if(YExtent>=0)
+            flipTrx.ApplyTransform(Img2->x, Img2->y);
+      }
+      //if(Img2->Vector)
+      //   Img2->Vector.Transform(flipTx);
+      Img2->x *= Scale;
+      Img2->y *= Scale;
+      Img2->dx *= Scale;
+      Img2->dy *= -Scale;      
+      Img2 = Img2->Next;       
+    }
+
+  if(VectList.VectorObjects>0 && Img.VecImage==NULL)
+  {    
+    Img.AttachVecImg(new VectorImage(VectList,PSS));
+
+    if(Img.dx!=0 && Img.dy!=0 && Img.Raster!=NULL)
+    {
+      if(Img.VecImage!=NULL)	// Move raster data to different image frame.
+      {
+        Img2 = &Img;
+        while(Img2->Next!=NULL)
+          Img2 = Img2->Next;
+        Img2->Next = new Image();
+        Img2 = Img2->Next;
+
+        Img2->x =  bbx.MinX * Scale;
+        Img2->y =  bbx.MinY * Scale;
+        Img2->dx = (bbx.MaxX - bbx.MinX) * Scale;
+        Img2->dy = (bbx.MaxY - bbx.MinY) * Scale;
+        Img2->VecImage = Img.VecImage; Img.VecImage=NULL;
+      }
+    }
+    else	// Use whole frame as bounding box.
+    {      
+      Img.x =  bbx.MinX * Scale;
+      Img.y =  bbx.MinY * Scale;
+      Img.dx = (bbx.MaxX - bbx.MinX) * Scale;
+      Img.dy = (bbx.MaxY - bbx.MinY) * Scale;  
+    }        
   }
-  return -10;
+
+    if(!NoConvertImage && (Img.Raster!=NULL || Img.VecImage!=NULL))
+    {
+    for(Image *pImg=&Img; pImg!=NULL; pImg=pImg->Next)
+      if(pImg->Raster!=NULL)
+        ReducePalette(pImg,256);
+
+    string NewFilename = MergePaths(OutputDir,RelativeFigDir) + GetFullFileName(GetSomeImgName(".eps"));
+    if(SavePictureEPS(NewFilename(),Img)<0)
+	{
+        if(err != NULL)
+	  {
+	  perc.Hide();
+	  fprintf(err, _("\nError: Cannot save file: \"%s\"!"), NewFilename());
+	  }
+	return 0;
+        }
+
+    NewFilename = CutFileName(NewFilename); 	//New Filename only
+
+    if(InputPS & IMG_graphicx)	//graphicx.sty
+      {
+      fprintf(strip," \\begin{center}");
+      fprintf(strip,"\\includegraphics");
+      fprintf(strip,"[width=\\textwidth]");
+      fprintf(strip,"{\\FigDir/%s.eps}",NewFilename() );
+      fprintf(strip," \\end{center}");
+      putc('\n',strip);  rownum++;
+    }
+    else if(InputPS & IMG_epsfig)	//epsfig.sty
+      {
+      fprintf(strip," \\begin{center}");
+      fprintf(strip,"\\epsfig{file=\\FigDir/%s.eps,",NewFilename() );
+      fprintf(strip,"width=\\textwidth");
+      putc('}',strip);
+      fprintf(strip," \\end{center}");
+      putc('\n',strip);  rownum++;
+      }
+    else if(InputPS & IMG_graphics)	//graphics.sty
+      {
+      fprintf(strip," \\begin{center}");
+      fprintf(strip,"\\includegraphics");
+      fprintf(strip,"{\\FigDir/%s.eps}",NewFilename() );
+      fprintf(strip," \\end{center}");
+      putc('\n',strip);  rownum++;
+      }
+    else			//InputPS.sty
+      {
+      fprintf(strip,"\\begin{forcewidth}");
+      fprintf(strip,"{\\textwidth}\n"); rownum++;
+      fprintf(strip," \\begin{center}");
+      fprintf(strip,"\\InputPS{\\FigDir/%s.eps}",NewFilename() );
+      putc('\n',strip);  rownum++;
+      fprintf(strip," \\end{center}");
+      putc('\n',strip);  rownum++;
+      fprintf(strip,"\\end{forcewidth}\n");  rownum++;
+      }
+
+    InputPS |= 1;		//mark style as used
+    Finalise_Conversion(this);
+    RetVal++;
+    }
+
+  OutCodePage = CodePageBk;
+  return(RetVal);
 }
 
 
