@@ -316,6 +316,7 @@ string TeX_RelativeFigDir;
     fprintf(LaTeX, "\\documentstyle[11pt,");
     if(Accents>=1)  fprintf(this->LaTeX, "accents,");
     if(Amssymb>=1)  fprintf(this->LaTeX, "amssymb,");
+    if(Arevmath>=1)  fprintf(this->LaTeX, "arevmath,");
     if(AmsMath>=1)   fprintf(this->LaTeX, "amsmath,");
     if(MakeIdx>=1)  fprintf(this->LaTeX, "makeidx,");
     if(Ulem>=1)     fprintf(this->LaTeX, "ulem,");
@@ -359,6 +360,7 @@ string TeX_RelativeFigDir;
     if(Accents>=1)  UsePackage("accents");
     if(Amssymb>=1)  UsePackage("amssymb");
     if(AmsMath>=1)  UsePackage("amsmath");
+    if(Arevmath>=1) UsePackage("arevmath");
     if(LaTeXsym>=1) UsePackage("latexsym");
     if(MakeIdx>=1)  UsePackage("makeidx");
     if(Ulem>=1)     UsePackage("ulem");
@@ -1365,25 +1367,27 @@ return(1);			//Line is Empty
 }
 
 
-/** This function groups multiple rows inside one table cell into a \shortstack*/
+/** This function groups multiple rows inside one table cell into a \shortstack
+ * @param[in,out]	aLine	Row string to be fixed. */
 static int OptimizeMultiRows(string & aLine)
 {
 string NewLine,Cell;
 int i;
-char *HelpS,*aLinePtr,OldChar;
+const char *HelpS, *aLinePtr;
+char OldChar;
 int shortstack;
 
-HelpS=StrStr(aLine(), "\\penalty-10001");
-shortstack=false;
-aLinePtr=aLine();
-OldChar=0;
-while(*aLinePtr!=0)
+ HelpS = StrStr(aLine(), "\\penalty-10001");
+ shortstack = 0;
+ aLinePtr = aLine();
+ OldChar = 0;
+ while(*aLinePtr!=0)
 	{
 	if(aLinePtr==HelpS)
 	     {
 	     i=0;
-	     HelpS=StrStr(++HelpS, "\\penalty-10001");
-	     aLinePtr+=strlen("\\penalty-10001");
+	     HelpS = StrStr(++HelpS, "\\penalty-10001");
+	     aLinePtr += strlen("\\penalty-10001");
 	     while(aLinePtr[i]==' ')
 		 {
 		 i++;
@@ -1403,6 +1407,7 @@ while(*aLinePtr!=0)
 	     }
 
 Reject:	if(OldChar!='\\')
+	{
 	  if(*aLinePtr==0 || *aLinePtr=='&' || (*aLinePtr=='\\' && aLinePtr[1]=='\\'))
 	     {
 	     NewLine+=Cell;
@@ -1412,25 +1417,39 @@ Reject:	if(OldChar!='\\')
 		 NewLine+='}';
 		 }
 
-	     NewLine+=OldChar=*aLinePtr++;
-	     Cell="";
+	     NewLine += OldChar = *aLinePtr++;
+	     Cell.erase();
 	     shortstack=0;
 	     continue;
 	     }
 
+          if(*aLinePtr=='$')		// Skip formula, formula is unbreakable.
+	     {
+	       do
+	         {
+	         Cell += OldChar = *aLinePtr++;	
+	         } while(*aLinePtr!='$' && *aLinePtr!=0);
+	       if(*aLinePtr ==0) break;
+	       if(HelpS < aLinePtr)
+	         {
+	         HelpS = StrStr(aLinePtr, "\\penalty-10001");
+		 }
+	     }
+        }
+
 	if(*aLinePtr!=' ') shortstack&=~2;
-	Cell+=OldChar=*aLinePtr++;
+	Cell += OldChar = *aLinePtr++;
 	}
 
-NewLine+=Cell;
-if(shortstack)
+ NewLine+=Cell;
+ if(shortstack)
    {
    if(shortstack>1) NewLine+="\\strut";
    NewLine+='}';
    }
 
-aLine=NewLine;
-return(shortstack);
+ aLine = NewLine;
+ return(shortstack);
 }
 
 
@@ -1557,7 +1576,7 @@ TconvertedPass2 cq2;
 
   for(i=0; i<=3; i++)
       {
-      cq2.Lines[i].Lstring = "";
+      cq2.Lines[i].Lstring.erase();
       cq2.Lines[i].Empty   = true;
       cq2.Lines[i].Columns = 1;
       cq2.Lines[i].InhibitBsBslash = false;
@@ -1971,7 +1990,7 @@ FixOpen:	  Open_All_Attr(cq2.Lines[cq2.cur].attr,*aLineStr);
       }
 
 EmptyThisLine:
-    cq2.Lines[cq2.pre].Lstring = "";
+    cq2.Lines[cq2.pre].Lstring.erase();
     cq2.Lines[cq2.pre].InhibitBsBslash = false;
 
     cq2.Select_NextLine();
