@@ -80,6 +80,7 @@ Flags:'h';       Hard return
 SBYTE   Accents = false,
 	AmsMath = -1,
         Amssymb = -1,		// Totaly Disabled
+	Arevmath = -1,		// Totaly Disabled
         Cyrillic = false,
 	cjHebrew = false,
 	colors = false,		// Only for LaTex 2.0e
@@ -150,6 +151,7 @@ FILE *strip, *logg, *err;
 FILE *latex;
 
 
+/// Opening and closing for styles in LaTeX v2
 const TStyleOpCl StyleOpCl2[] =
 {
   {"{\\LARGE ",        "}",    NULL,       NULL},
@@ -185,6 +187,7 @@ const TStyleOpCl StyleOpCl2[] =
 };
 
 
+/// Opening and closing for styles in LaTeX v3
 const TStyleOpCl StyleOpCl3[] =
 {
   {"{\\LARGE ",        "}",    NULL,       NULL},
@@ -224,10 +227,6 @@ const TStyleOpCl *StyleOpCl = StyleOpCl2;
 
 
 
-//const char * const* Open_com = Open_com2;
-//const char * const* Close_com = Close_com2;
-
-
 int OutputStyle = First_com_section + 2;
 
 #if defined(__BORLANDC__) && defined(__MSDOS__)
@@ -412,7 +411,7 @@ const char EncryptionWarning[]=N_("\nWarning: File seems to be encrypted. Conver
 #define MaxChar 0x200   //this can be used to tune a quality of autodetection
 
 
-/*This procedure provides autodetection of Accent format*/
+/// This procedure provides autodetection of Accent format.
 static int DetectAccent(FILE *text, FFormatDetect & iFFD)
 {
 int Status,CharNo=0,chr;
@@ -485,7 +484,7 @@ char buffer[2];
 
 
 
-//This is a state machine for detecting HTML files
+/// This is a state machine for detecting HTML files
 static int DetectHtml(FILE *text, FFormatDetect & iFFD)
 {
 int Status,CharNo=0,chr;
@@ -551,7 +550,7 @@ NoHTML:
 }
 
 
-/*This procedure provides autodetection of MTEF format*/
+/// This procedure provides autodetection of MTEF format.
 static int DetectMTEF(FILE *stream, FFormatDetect & iFFD)
 {
 DWORD Version,ObjLen,FileSize;
@@ -587,7 +586,7 @@ NoMTEF:
 }
 
 
-/*This procedure provides autodetection of postscript text*/
+/** This procedure provides autodetection of postscript text. */
 static int DetectPostScript(FILE *stream, FFormatDetect & iFFD)
 {
 WORD Magic1,Magic2;
@@ -608,7 +607,7 @@ WORD Magic1,Magic2;
 }
 
 
-/*This procedure provides autodetection of RTF format*/
+/** This procedure provides autodetection of RTF format. */
 static int DetectRTF(FILE *text, FFormatDetect & iFFD)
 {
 long OldFilePos;
@@ -619,7 +618,7 @@ char buffer[6];
 
   if(text==NULL) return(0);
 
-  OldFilePos=ftell(text);
+  OldFilePos = ftell(text);
 
   if(fread(buffer,1,5,text)!=5) goto NoRTF;
   if(!strncmp(buffer,"{\\rtf",5))		//RTF startup detected
@@ -634,7 +633,7 @@ NoRTF:
 }
 
 
-/*This procedure provides autodetection of RTF format*/
+/** This procedure provides autodetection of RTF format. */
 static int DetectT602(FILE *text, FFormatDetect & iFFD)
 {
 long OldFilePos;
@@ -644,7 +643,7 @@ int commands=0,len;
   iFFD.DocumentType = "Text 602";
   iFFD.Extension = iFFD.Converter = "T602";
   if(text==NULL) return(0);
-  OldFilePos=ftell(text);
+  OldFilePos = ftell(text);
 
   while(!feof(text))
     {
@@ -810,7 +809,7 @@ XML_Detected:
 }
 
 
-/**This procedure provides autodetection of OLE stream wrapper format*/
+/** This procedure provides autodetection of OLE stream wrapper format. */
 static int DetectOLEStream(FILE *stream, FFormatDetect & iFFD)
 {
 DWORD Magic1,Magic2;
@@ -830,7 +829,7 @@ DWORD Magic1,Magic2;
 
 
 #ifndef NO_IMG
-/**This procedure provides autodetection of PNG format.*/
+/// This procedure provides autodetection of PNG format.
 static int DetectPNG(FILE *stream, FFormatDetect & iFFD)
 {
 static const unsigned char PngSignature[8] = {0x89,'P','N','G',0x0D, 0x0A, 0x1A, 0x0A};
@@ -843,17 +842,17 @@ char buffer[sizeof(PngSignature)];
 
   if(fread(buffer,1,sizeof(PngSignature),stream)!=8) 
     {
-    fseek(stream,-sizeof(PngSignature),SEEK_CUR);
+    fseek(stream,-(long)sizeof(PngSignature),SEEK_CUR);
     return 0;
     }
-  fseek(stream,-sizeof(PngSignature),SEEK_CUR);
+  fseek(stream,-(long)sizeof(PngSignature),SEEK_CUR);
   if(!memcmp(buffer,PngSignature,sizeof(PngSignature))) return 1;
   return(0);
 }
 #endif
 
 
-/**This procedure provides autodetection of unicode plain text*/
+/// This procedure provides autodetection of unicode plain text.
 static int DetectUnicode(FILE *stream, FFormatDetect & iFFD)
 {
 WORD Magic1;
@@ -888,13 +887,13 @@ BYTE Magic2,Check3;
 }
 
 
-/* Checks whether the given document is a valid Microsoft Word document.
+/** Checks whether the given document is a valid Microsoft Word document.
  * For WORD>=8.x thich check inner OLE file  */
 int DetectWord(FILE *f, FFormatDetect & iFFD)
 {
 WORD wIdent;			/* 0x0000 */
 WORD nFib;			/* 0x0002 */
-DWORD CurrentPos;
+long CurrentPos;
 DWORD cbMac=0xFFFF;
 
   iFFD.DocumentType="Microsoft Word";
@@ -903,7 +902,7 @@ DWORD cbMac=0xFFFF;
 
   iFFD.DocVersion = 0x800;
 
-  CurrentPos=ftell(f);
+  CurrentPos = ftell(f);
   Rd_word(f,&wIdent);
   Rd_word(f,&nFib);
 
@@ -960,7 +959,7 @@ int DetectWordPerfect(FILE *wpd, FFormatDetect & iFFD)
 DWORD id;
 WORD filetype, ver, encryption, dmp3;
 DWORD StartDoc;
-DWORD FilePos;
+long FilePos;
 
   iFFD.Converter = NULL;
   iFFD.Extension = "WP";
@@ -1032,6 +1031,7 @@ DWORD FilePos;
 	case 0x30:iFFD.DocumentType="Macintosh soft graphics";break;
 
 	case 0x38:iFFD.DocumentType="WPWin5.1 App Resource library";break;
+        case 0x3A:iFFD.DocumentType="WP5.2 Far east";break;
 	}
 
     if(filetype>>8 == 0x16)
@@ -1064,15 +1064,22 @@ DWORD FilePos;
 
 	}
 
-    if (filetype == 0xA01)
+    if(filetype==0x3A01)
+        {
+    	iFFD.DocumentStart = StartDoc;
+        iFFD.DocVersion=0x500 + (WORD)(ver>>8);
+        iFFD.Converter = "WP5.FarEast";
+        }
+
+    if(filetype==0xA01)
 	   /*   version == 0x0000 -> WP 5.0
 	    *   version == 0x0100 -> WP 5.1
 	    *   version == 0x0002 -> WP 6.0
 	    *   version == 0x0102 -> WP 6.1
 	    *   version == 0x0202 -> WP 7.0  */
-       {
-       iFFD.DocumentStart = StartDoc;
-       switch(ver & 0xFF)  // major version
+         {
+         iFFD.DocumentStart = StartDoc;
+         switch(ver & 0xFF)  // major version
 	   {
 	   case 0:iFFD.DocVersion=0x500 + (WORD)(ver>>8);
 		  if(encryption==0) iFFD.Converter="WP5.x";
@@ -1129,15 +1136,15 @@ BYTE ObjWP1SizesC0[]=
 /** Common detection procedure for both WP1Mac and WP4PC. */
 static int DetectWP1and4(FILE *wpd, BYTE *ObjWPxSizesC0)
 {
-DWORD FilePos;
+long FilePos;
 BYTE w,Flag;
 int WP_hit;
 unsigned CharNo;
 
-  FilePos=ftell(wpd);
+  FilePos = ftell(wpd);
 
-  WP_hit=0;
-  CharNo=0;
+  WP_hit = 0;
+  CharNo = 0;
   while(!feof(wpd) && CharNo<MaxChar)
      {
      const BYTE c = fgetc(wpd);	CharNo++;
@@ -1373,6 +1380,8 @@ static const PkgItem PkgList[] =
 	{{"accents",&Accents, N_("Use accents to support additional accents.")},
         {"amssymb",&Amssymb,NULL},
         {"Amssymb",&Amssymb, N_("Use AMSsymb with special characters.")},
+	{"arevmath",&Arevmath,NULL},
+        {"Arevmath",&Arevmath, N_("Use arevmath with special characters.")},
         {"amsmath",&AmsMath,NULL},
         {"AmsMath",&AmsMath, N_("Use AmsMath with special characters.")},
         {"bbm",&Bbm,NULL},
